@@ -21,6 +21,7 @@ def join_lines(lines):
 
 def make_slug(s):
     s = unidecode(s).lower()
+    print("unidecode: ", s)
     s2 = ""
     for c in s:
         if c.isalnum():
@@ -34,6 +35,8 @@ def make_slug(s):
 def make_problem_code(name):
     name = make_slug(name)
     name = name.strip(" _").replace("-", "_")
+    if not name:
+        return name
     if '0' <= name[0] <= '9':
         name = "p" + name
     return name
